

#include "./USB/usb.h"
#include "HardwareProfile.h"
#include "./USB/usb_function_cdc.h"

static void InitializeSystem(void);
void ProcessIO(void);
void USBDeviceTasks(void);
void UserInit(void);

static void InitializeSystem(void)
{
      {
        unsigned int pll_startup_counter = 600;
        CLKDIVbits.PLLEN = 1;
        while(pll_startup_counter--);
      }
    
    #if defined(USE_USB_BUS_SENSE_IO)
      tris_usb_bus_sense = INPUT_PIN; // See HardwareProfile.h
    #endif

    #if defined(USE_SELF_POWER_SENSE_IO)
      tris_self_power = INPUT_PIN;	// See HardwareProfile.h
    #endif

      USBDeviceInit();
}


int ADCValue, count;
int *ADC16Ptr;

void readadc()
{
   ADCValue = 0; // clear value
   ADC16Ptr = &ADC1BUF0; // initialize ADC1BUF pointer
   IFS0bits.AD1IF = 0; // clear ADC interrupt flag
   AD1CON1bits.ASAM = 1; // auto start sampling for 31Tad
   // then go to conversion
     while (!IFS0bits.AD1IF){}; // conversion done?
     AD1CON1bits.ASAM = 0; // yes then stop sample/convert
      for (count = 0; count < 16; count++) // average the 16 ADC value
          {
             ADCValue = ADCValue + *ADC16Ptr++;
          }
         ADCValue = ADCValue >> 4; 
}

void __attribute__((interrupt, no_auto_psv)) _T1Interrupt(void)
{
        //LATBbits.LATB7=~LATBbits.LATB7;
        readadc();

        /* 
           Config  */
         char data[100];
         unsigned int ii=0;
  if(mUSBUSARTIsTxTrfReady())
    { 
        ii=TMR2; TMR2=0;
        sprintf(data,"%u",ADCValue);  
        putsUSBUSART(data);
      
    }

    CDCTxService();
    IFS0bits.T1IF = 0; //Reset Timer1 interrupt flag and Return from ISR
}


void USBCBSuspend(void)
{
}

void USBCBWakeFromSuspend(void)
{
}

void USBCB_SOF_Handler(void)
{
}

void USBCBErrorHandler(void)
{
}

void USBCBCheckOtherReq(void)
{
    USBCheckCDCRequest();
}

void USBCBStdSetDscHandler(void)
{    
}

void USBCBInitEP(void)
{
    CDCInitEP();
}

void USBCBSendResume(void)
{
    static WORD delay_count;
    
    if(USBGetRemoteWakeupStatus() == TRUE) 
    {

        if(USBIsBusSuspended() == TRUE)
        {
            USBMaskInterrupts();
            
            USBCBWakeFromSuspend();
            USBSuspendControl = 0; 
            USBBusIsSuspended = FALSE;

            delay_count = 3600U;        
            do
            {
                delay_count--;
            } while(delay_count);
            
            USBResumeControl = 1;
            delay_count = 1800U;
            do
            {
                delay_count--;
            } while(delay_count);
            USBResumeControl = 0;

            USBUnmaskInterrupts();
        }
    }
}

#if defined(ENABLE_EP0_DATA_RECEIVED_CALLBACK)
   void USBCBEP0DataReceived(void)
     {
     }
#endif


BOOL USER_USB_CALLBACK_EVENT_HANDLER(USB_EVENT event, void *pdata, WORD size)
{
    switch(event)
    {
        case EVENT_TRANSFER:
            //Add application specific callback task or callback function here if desired.
            break;
        case EVENT_SOF:
            USBCB_SOF_Handler();
            break;
        case EVENT_SUSPEND:
            USBCBSuspend();
            break;
        case EVENT_RESUME:
            USBCBWakeFromSuspend();
            break;
        case EVENT_CONFIGURED: 
            USBCBInitEP();
            break;
        case EVENT_SET_DESCRIPTOR:
            USBCBStdSetDscHandler();
            break;
        case EVENT_EP0_REQUEST:
            USBCBCheckOtherReq();
            break;
        case EVENT_BUS_ERROR:
            USBCBErrorHandler();
            break;
        case EVENT_TRANSFER_TERMINATED:
            //Add application specific callback task or callback function here if desired.
            //The EVENT_TRANSFER_TERMINATED event occurs when the host performs a CLEAR
            //FEATURE (endpoint halt) request on an application endpoint which was 
            //previously armed (UOWN was = 1).  Here would be a good place to:
            //1.  Determine which endpoint the transaction that just got terminated was 
            //      on, by checking the handle value in the *pdata.
            //2.  Re-arm the endpoint if desired (typically would be the case for OUT 
            //      endpoints).
            break;
        default:
            break;
    }      
    return TRUE; 
}
